@@ -10,7 +10,7 @@ function(x,m,a,n=NULL,p0=NULL)
 	q=0;
 	if(re==-1)
 	{
-		return(-1);
+		return(data.frame("state"=-1,"pvalue"=1));
 	}
 	else
 	{
@@ -55,18 +55,19 @@ function(x,m,a,n=NULL,p0=NULL)
 			q=q+(y[i]-(length(x)*p[i]))^2/(length(x)*p[i]);
 		}
 		q0=qchisq(1-a,df);
+                pvalue=pchisq(q,df);
 		if(q<=q0)
 		{
-			return(q0-q);
+			return(data.frame("qchisq"=q,"pvalue"=pvalue));
 		}
 		else 
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 		}
 		else
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 	}
 }
