@@ -10,7 +10,7 @@ function(x,m,a,lambda=NULL)
 	q=0;
 	if(re==-1)
 	{
-		return(-1);
+		return(data.frame("state"=-1,"pvalue"=1));
 	}
 	else
 	{
@@ -41,18 +41,19 @@ function(x,m,a,lambda=NULL)
 			p[m+1]=pexp(Inf,lambda)-pexp(max(x),lambda);
 			q=q+length(x)*p[m+1];
 			q0=qchisq(1-a,df);
+                        pvalue=pchisq(q,df);
 			if(q<=q0)
 			{
-				return(q0-q);
+				return(data.frame("qchisq"=q,"pvalue"=pvalue));
 			}
 			else
 			{
-				return(-1);
+				return(data.frame("state"=-1,"pvalue"=1));
 			}
 		}
 		else
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 	}
 }
