@@ -10,7 +10,7 @@ function(x,m,a,a0=NULL,b0=NULL)
 	q=0;
 	if(re==-1)
 	{
-		return(-1);
+		return(data.frame("state"=-1,"pvalue"=1));
 	}
 	else
 	{
@@ -60,18 +60,19 @@ function(x,m,a,a0=NULL,b0=NULL)
 		if(p[m+2]!=0)
 			q=q+(y[m+2]-(length(x)*p[m+2]))^2/(length(x)*p[m+2]);
 		q0=qchisq(1-a,df);
+                pvalue=pchisq(q,df);
                 if(q<=q0)
 		{
-			return(q0-q);
+			return(data.frame("qchisq"=q,"pvalue"=pvalue));
 		}
 		else
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 		}
 		else
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 	}
 }
