@@ -7,7 +7,7 @@ function(x,a,p0=NULL)
 			re=-1;
 	if(re==-1)
 	{
-		return(-1);
+		return(data.frame("state"=-1,"pvalue"=1));
 	}
 	else
 	{
@@ -41,18 +41,19 @@ function(x,a,p0=NULL)
 		p[max(x)+1]=1-pgeom(max(x)-1,p0);
 		q=q+length(x)*p[max(x)+1];
 		q0=qchisq(1-a,df);
+                pvalue=pchisq(q,df);
 		if(q<=q0)
 		{
-			return(q0-q);
+			return(data.frame("qchisq"=q,"pvalue"=pvalue));
 		}
 		else
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 		}
 		else 
 		{
-			return(-1);
+			return(data.frame("state"=-1,"pvalue"=1));
 		}
 	}
 }
